﻿//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  Anwendung                                                                           //
//  _________________________________                                                   //
//                                                                                      //
//  Copyright (c) 2024 Reimar Grasbon													//
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  This software is subjected to the FreeBSD License. Redistribution and use in source //
//  and binary forms, with or without modification, are permitted provided that the     //
//  following conditions are met:                                                       //
//                                                                                      //
//  1. Redistributions of source code must retain the above copyright notice, this list //
//     of conditions and the following disclaimer.                                      //
//                                                                                      //
//  2. Redistributions in binary form must reproduce the above copyright notice, this   //
//     list of conditions and the following disclaimer in the documentation and/or      //
//     other materials provided with the distribution.                                  //
//                                                                                      //
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY //
//  EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED           //
//  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  //
//  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,    //
//  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT  //
//  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR  //
//  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,   //
//  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)  //
//  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE          //
//  POSSIBILITY OF SUCH DAMAGE.                                                         //
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////

#pragma once

#include "TypeDefs.h"
#include "LightSignal.h"
#include "ToneSignal.h"

//////////////////////////////////////////////////////////////////////////////////////////
//  Typen  ///////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
typedef struct                             // Bus-Aktivitätsanzeige auf der LED:
{	bool			  enabled;		       // · 'true' = ein
	UInt08			  brightness;          // · Helligkeit: 10% .. 100%
} LedBusActivity;

typedef enum                               // Aufgabe eines Kontaktes im Alarmsystem:
{   CONTACT_ALARM_ROLE_NONE       = 0,     // · Kontakt hat keine Aufgabe
	CONTACT_ALARM_ROLE_ACTIVATE   = 1,     // · Kontaktereignis aktiviert
	CONTACT_ALARM_ROLE_DEACTIVATE = 2,     // · Kontaktereignis deaktiviert
	CONTACT_ALARM_ROLE_TOGGLE     = 3,     // · Kontaktereignis aktiviert und deaktiviert
	CONTACT_ALARM_ROLE_TRIGGER    = 4,     // · Kontaktereignis löst Alarm aus
} ContactAlarmRole;

typedef struct 						       // Ereignis-Signalisierungen der Alarmeinheit:
{   ToneEventSignal   toneSignal;	       // · Tonsignal bei Eintritt des Ereignisses
	LightEventSignal  lightSignal;         // · Lichtsignal bei Eintritt des Ereignisses
	UInt08            brightness;          // · Helligkeit des Lichtsignals
} EventSignal;

typedef struct                             // Zustands-Signalisierungen der Alarmeinheit:
{	ToneStateSignal	  toneSignal;	       // · Tonsignal während des Zustandes
	LightStateSignal  lightSignal;	       // · Lichtsignal während des Zustandes
	UInt08            brightness;          // · Helligkeit des Lichtsignals
} StateSignal;

typedef struct                                    // Konfiguration der Kontakt-Ereignisse:
{   UInt08            stateDurationUntilEvent;    // · Zustandsdauer bis Ereignis eintritt
	EventSignal		  eventSignal;			      // · Signale bei Eintritt des Ereignisses
	ContactAlarmRole  alarmRole;                  // · Aufgabe des Kontaktes im Alarmsystem
} ContactEventConfiguration;

typedef enum							   // Schaltausgang-Aktivität:
{	SWITCH_ACTION_NONE = 0,				   // · Schaltausgang wird eingeschaltet
	SWITCH_ACTION_ON   = 1,     		   // · Schaltausgang wird ausgeschaltet
	SWITCH_ACTION_OFF  = 2   			   // · Schaltausgang wird ausgeschaltet
} SwitchAction;

//////////////////////////////////////////////////////////////////////////////////////////
//  Prozessaufrufe  //////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
void           APPLICATION_Startup(void);
void           APPLICATION_Proceed(void);
void           APPLICATION_Shutdown(void);

//////////////////////////////////////////////////////////////////////////////////////////

